@@ -38,6 +38,10 @@ def get_modules(prefix, parent):
 
 class WebApplication(Application):
     def __call__(self, request): 
+        transforms = [t(request) for t in self.transforms]
+        handler = None
+        args = []
+        kwargs = {}
         if request.path.endswith("/"):
             if request.method in ("GET", "HEAD"):
                 uri = request.path.rstrip("/")
@@ -144,7 +148,7 @@ class WSGIApplication(_WSGIApplication):
         return handler._write_buffer
 
 
-class DebugApplication(Application):
+class DebugApplication(WebApplication):
     "Tornado Application supporting werkzeug interactive debugger."
  
     # This supports get_error_html in Handler above.
